==> apache-ignite-2.9.0-src.zip: apache-ignite-2.9.0-src/docs/_docs/code-snippets/java/src/main/java/org/apache/ignite/snippets/k8s/K8s.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ignite.snippets.k8s;

import org.apache.ignite.Ignition;
import org.apache.ignite.client.ClientCache;
import org.apache.ignite.client.IgniteClient;
import org.apache.ignite.configuration.ClientConfiguration;

public class K8s {

    public static void connectThinClient() throws Exception {
        // tag::connectThinClient[]
        ClientConfiguration cfg = new ClientConfiguration().setAddresses("13.86.186.145:10800");
        IgniteClient client = Ignition.startClient(cfg);

        ClientCache<Integer, String> cache = client.getOrCreateCache("test_cache");

        cache.put(1, "first test value");

        System.out.println(cache.get(1));

        client.close();
        // end::connectThinClient[]
    }
}

==> apache-ignite-2.11.1-src.zip: apache-ignite-2.11.1-src/docs/_docs/code-snippets/java/src/main/java/org/apache/ignite/snippets/k8s/K8s.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ignite.snippets.k8s;

import org.apache.ignite.Ignition;
import org.apache.ignite.client.ClientCache;
import org.apache.ignite.client.IgniteClient;
import org.apache.ignite.configuration.ClientConfiguration;

public class K8s {

    public static void connectThinClient() throws Exception {
        // tag::connectThinClient[]
        ClientConfiguration cfg = new ClientConfiguration().setAddresses("13.86.186.145:10800");
        IgniteClient client = Ignition.startClient(cfg);

        ClientCache<Integer, String> cache = client.getOrCreateCache("test_cache");

        cache.put(1, "first test value");

        System.out.println(cache.get(1));

        client.close();
        // end::connectThinClient[]
    }

    public static void connectThinClientWithConfiguration() throws Exception {
        // tag::connectThinClientWithKubernetesConfiguration[]
        KubernetesConnectionConfiguration kcfg = new KubernetesConnectionConfiguration();
        kcfg.setNamespace("ignite");
        kcfg.setServiceName("ignite-service");

        ClientConfiguration ccfg = new ClientConfiguration();
        ccfg.setAddressesFinder(new ThinClientKubernetesAddressFinder(kcfg));

        IgniteClient client = Ignition.startClient(cfg);

        ClientCache<Integer, String> cache = client.getOrCreateCache("test_cache");

        cache.put(1, "first test value");

        System.out.println(cache.get(1));

        client.close();
        // end::connectThinClientWithKubernetesConfiguration[]
    }
}
